| Title: | Analysis of Chromosome Conformation Capture and Next-generation Sequencing (3C-seq) |
|---|---|
| Description: | This package is used for the analysis of long-range chromatin interactions from 3C-seq assay. |
| Authors: | Supat Thongjuea, MRC WIMM Centre for Computational Biology, Weatherall Institute of Molecular Medicine, University of Oxford, UK <[email protected]> |
| Maintainer: | Supat Thongjuea <[email protected]> or <[email protected]> |
| License: | GPL-3 |
| Version: | 1.59.0 |
| Built: | 2026-05-30 07:22:08 UTC |
| Source: | https://github.com/bioc/r3Cseq |
Normalize 3C-Seq data by transforming raw reads to read per million per each region for replication analysis
calculateBatchRPM(object,normalized_method=c("powerlawFittedRPM","normalRPM"))calculateBatchRPM(object,normalized_method=c("powerlawFittedRPM","normalRPM"))
object |
r3CseqInBatch object |
normalized_method |
character. method of normalization (default=powerlawFittedRPM) |
S. Thongjuea
#See the vignette#See the vignette
Normalize 3C-Seq data by transforming raw reads to read per million per each region
calculateRPM(object,normalized_method=c("powerlawFittedRPM","normalRPM"))calculateRPM(object,normalized_method=c("powerlawFittedRPM","normalRPM"))
object |
r3Cseq object |
normalized_method |
character. method of normalization (default=powerlawFittedRPM) |
S. Thongjuea
contrRPM, expRPM, calculateBatchRPM
#See the vignette#See the vignette
get all identified interaction regions from the control
contrInteractionRegions(object)contrInteractionRegions(object)
object |
r3Cseq or r3CseqInBatch object |
The candidate interaction regions show in the IRange object
S. Thongjuea
expInteractionRegions, getInteractions
#See the vignette#See the vignette
The 'contrRawData' slot of hold the raw aligned reads data in the GRanges object.
## S4 method for signature 'r3Cseq' contrRawData(object) ## S4 replacement method for signature 'r3Cseq' contrRawData(object) <- value## S4 method for signature 'r3Cseq' contrRawData(object) ## S4 replacement method for signature 'r3Cseq' contrRawData(object) <- value
object |
r3Cseq object |
value |
a GRanges object of aligned reads |
S. Thongjuea
#See the vignette#See the vignette
get the read count per region for the control
contrReadCount(object)contrReadCount(object)
object |
r3Cseq object |
S. Thongjuea
expReadCount, getReadCountPerRestrictionFragment
#See the vignette#See the vignette
get the normalized 3C-seq data (RPM) for the control
contrRPM(object)contrRPM(object)
object |
r3Cseq or r3CseqInBatch object |
S. Thongjuea
#See the vignette#See the vignette
The database includes all restriction enzyme information from the REBASE database.
http://rebase.neb.com/rebase/rebase.html
get identified interaction regions from the experiment
expInteractionRegions(object)expInteractionRegions(object)
object |
r3Cseq or r3CseqInBatch object |
The candidate interaction regions show in the IRange object
S. Thongjuea
getInteractions, contrInteractionRegions
#See the vignette#See the vignette
export interaction regions from RagedData to the bedGraph format, which suitable for uploading to the UCSC genome browser
export3Cseq2bedGraph(object,datatype=c("rpm","read_count"))export3Cseq2bedGraph(object,datatype=c("rpm","read_count"))
object |
r3Cseq object, The object might contain the interaction regions generated by function getInteractions |
datatype |
read_count : read count per restriction fragment rpm : normalized read per million per restriction fragment |
The text file in 'bedGraph' format
S. Thongjuea
#See the vignette#See the vignette
export interaction regions signal to the bedGraph format, which suitable for uploading to the UCSC genome browser
export3CseqRawReads2bedGraph(object)export3CseqRawReads2bedGraph(object)
object |
r3Cseq object |
The text file in 'bedGraph' format
S. Thongjuea
exportInteractions2text, export3Cseq2bedGraph,
#See the vignette#See the vignette
export interaction regions from RagedData to the tab separated format for replicates analysis
exportBatchInteractions2text(object)exportBatchInteractions2text(object)
object |
r3CseqInBatch object |
The text file in the tab separated format
S. Thongjuea
export3Cseq2bedGraph, exportInteractions2text
#See the vignette#See the vignette
export interaction regions from RagedData to the tab separated format
exportInteractions2text(object)exportInteractions2text(object)
object |
r3Cseq object |
The text file in the tab separated format
S. Thongjuea
#See the vignette#See the vignette
The 'expRawData' slot of hold the raw aligned reads data in the GRanges object.
## S4 method for signature 'r3Cseq' expRawData(object) ## S4 replacement method for signature 'r3Cseq' expRawData(object) <- value## S4 method for signature 'r3Cseq' expRawData(object) ## S4 replacement method for signature 'r3Cseq' expRawData(object) <- value
object |
r3Cseq object |
value |
a GRanges object of aligned reads |
S. Thongjuea
#See the vignette#See the vignette
get the read count per region for the experiment
expReadCount(object)expReadCount(object)
object |
r3Cseq |
S. Thongjuea
contrReadCount, getReadCountPerRestrictionFragment
#See the vignette#See the vignette
get the normalized 3C-seq data (RPM) for the experiment
expRPM(object)expRPM(object)
object |
r3Cseq or r3CseqInBatch |
S. Thongjuea
#See the vignette#See the vignette
generate reports for analysis results from r3Cseq, the report contains all plots in one pdf file and a text separated out put file.
generate3CseqReport(obj)generate3CseqReport(obj)
obj |
r3Cseq or r3CseqInBatch object |
The text file in the tab separated format and the pdf file of all plots
S. Thongjuea
exportInteractions2text plotOverviewInteractions, plotInteractionsPerChromosome, plotInteractionsNearViewpoint
#See the vignette#See the vignette
Calculate z-score, assign p-value and q-value to each interaction regions for replicates data sets
getBatchInteractions(object,method=c("union","intersection"),smoothing.parameter=0.1,fdr=0.05)getBatchInteractions(object,method=c("union","intersection"),smoothing.parameter=0.1,fdr=0.05)
object |
r3Cseq object |
method |
character. The method for combining biological replicates for 3C-Seq analysis (default = "union") |
smoothing.parameter |
A level at which cubic smoothing spline for the spar (see vsmooth.spline) input parameter. Must be in (0.06,0.4] (default=0.1) |
fdr |
A level at which to control the FDR. Must be in (0,1] (default=0.05) |
The interaction regions show in the RangedData
S. Thongjuea
getInteractions vsmooth.spline
#See the vignette#See the vignette
Reading in the input BAM files from the 3C-Seq replicates analysis and then save files as the local GRanged object .rData files
getBatchRawReads(object)getBatchRawReads(object)
object |
r3CseqInBatch object |
The GRangedData represents the aligned reads from the BAM file
S. Thongjuea
#See the vignette#See the vignette
Counts the number of reads from 3C-Seq data per each restriction fragment for replicates analysis
getBatchReadCountPerRestrictionFragment(object,getReadsMethod = c("wholeReads", "adjacentFragmentEndsReads"), nFragmentExcludedReadsNearViewpoint=2)getBatchReadCountPerRestrictionFragment(object,getReadsMethod = c("wholeReads", "adjacentFragmentEndsReads"), nFragmentExcludedReadsNearViewpoint=2)
object |
r3CseqInBatch object |
getReadsMethod |
character. To count all reads found in the particular restriction fragment uses wholeReads option. To count reads found around the edge of restriction fragment both 5'utr and 3'utr uses adjacentFragmentEndsReads option (default=wholeReads) |
nFragmentExcludedReadsNearViewpoint |
Numeric. The number of excluded fragments around the viewpoint, reads found in these fragments will be removed from the analysis (default=2) |
The RangedData represents the number of reads per each restriction fragment
S. Thongjuea
getReadCountPerWindow, getReadCountPerRestrictionFragment
#See the vignette#See the vignette
Counts the number of reads from 3C-Seq data per each window size for replicates analysis
getBatchReadCountPerWindow(object,windowSize=5e3,nFragmentExcludedReadsNearViewpoint=2,mode=c("non-overlapping", "overlapping"))getBatchReadCountPerWindow(object,windowSize=5e3,nFragmentExcludedReadsNearViewpoint=2,mode=c("non-overlapping", "overlapping"))
object |
r3CseqInBatch object |
windowSize |
Numeric. non-overlapping window size for counting reads (default=5e3) |
nFragmentExcludedReadsNearViewpoint |
Numeric. The number of excluded fragments around the viewpoint, reads found in these fragments will be removed from the analysis (default=2) |
mode |
character. The window-based modes analysis (default="non-overlapping") |
The RangedData represents the number of reads per each window size
S. Thongjuea
getReadCountPerRestrictionFragment, getBatchReadCountPerRestrictionFragment, getReadCountPerWindow,
#See the vignette#See the vignette
Get a list of genes that contain strong interaction signals in the control
getContrInteractionsInRefseq(obj,cutoff.qvalue=0.05,expanded_upstream=50e3,expanded_downstream=10e3)getContrInteractionsInRefseq(obj,cutoff.qvalue=0.05,expanded_upstream=50e3,expanded_downstream=10e3)
obj |
obj is r3Cseq or r3CseqInBatch object |
cutoff.qvalue |
Numeric. The cutoff q-value (default=0.05) |
expanded_upstream |
Numeric. The expanded distance from the upstream of a gene start (default=50e3) |
expanded_downstream |
Numeric. The expanded distance from the downstream of a gene end (default =10e3) |
List of identified genes, which contain strong interaction signals
S. Thongjuea
# See the vignette# See the vignette
Get a list of genes that contain strong interaction signals in the experiment
getExpInteractionsInRefseq(obj,cutoff.qvalue=0.05,expanded_upstream=50e3,expanded_downstream=10e3)getExpInteractionsInRefseq(obj,cutoff.qvalue=0.05,expanded_upstream=50e3,expanded_downstream=10e3)
obj |
obj is r3Cseq or r3CseqInBatch object |
cutoff.qvalue |
Numeric. The cutoff q-value (default=0.05) |
expanded_upstream |
Numeric. The expanded distance from the upstream of a gene start (default=50e3) |
expanded_downstream |
Numeric. The expanded distance from the downstream of a gene end (default =10e3) |
List of identified genes, which contain strong interaction signals
S. Thongjuea
# See the vignette# See the vignette
Calculate z-score, assign p-value and q-value to each interaction regions
getInteractions(object,smoothing.parameter=0.1,fdr=0.05)getInteractions(object,smoothing.parameter=0.1,fdr=0.05)
object |
r3Cseq object |
smoothing.parameter |
A level at which cubic smoothing spline for the spar (see vsmooth.spline) input parameter. Must be in (0.06,0.4] (default=0.1) |
fdr |
A level at which to control the FDR. Must be in (0,1] (default=0.05) |
The interaction regions show in the RangedData
S. Thongjuea
getBatchInteractions vsmooth.spline
#See the vignette#See the vignette
Reading in the input BAM file and then store it in the GRanged object
getRawReads(object)getRawReads(object)
object |
r3Cseq object |
The GRangedData represents the aligned reads from the BAM file
S. Thongjuea
#See the vignette#See the vignette
Counts the number of reads from 3C-Seq data per each restriction fragment
getReadCountPerRestrictionFragment(object,getReadsMethod = c("wholeReads", "adjacentFragmentEndsReads"), nFragmentExcludedReadsNearViewpoint=2)getReadCountPerRestrictionFragment(object,getReadsMethod = c("wholeReads", "adjacentFragmentEndsReads"), nFragmentExcludedReadsNearViewpoint=2)
object |
r3Cseq object |
getReadsMethod |
character. To count all reads found in the particular restriction fragment uses wholeReads option. To count reads found around the edge of restriction fragment both 5'utr and 3'utr uses adjacentFragmentEndsReads option (default=wholeReads) |
nFragmentExcludedReadsNearViewpoint |
Numeric. The number of excluded fragments around the viewpoint, reads found in these fragments will be removed from the analysis (default=2) |
The RangedData represents the number of reads per each restriction fragment
S. Thongjuea
getReadCountPerWindow, getBatchReadCountPerRestrictionFragment
#See the vignette#See the vignette
Counts the number of reads from 3C-Seq data per each window size
getReadCountPerWindow(object,windowSize=5e3,nFragmentExcludedReadsNearViewpoint=2,mode=c("non-overlapping"))getReadCountPerWindow(object,windowSize=5e3,nFragmentExcludedReadsNearViewpoint=2,mode=c("non-overlapping"))
object |
r3Cseq object |
windowSize |
Numeric. non-overlapping window size for counting reads (default=5e3) |
nFragmentExcludedReadsNearViewpoint |
Numeric. The number of excluded fragments around the viewpoint, reads found in these fragments will be removed from the analysis (default=2) |
mode |
character. The window-based modes analysis (default="non-overlapping") |
The RangedData represents the number of reads per each window size
S. Thongjuea
getReadCountPerRestrictionFragment,
#See the vignette#See the vignette
The viewpoint is the bait of 3C method, which can be a promoter region of an interested gene, an enhancer, and a transcrition factor binding region.
getViewpoint(obj)getViewpoint(obj)
obj |
r3Cseq or r3CseqInBatch object |
The viewpoint shows in the IRanges
S. Thongjuea
#See the vignette#See the vignette
The example aligned reads generated by 3C-Seq protocol from fetal brain. The promoter region of the Myb's gene was selected as the viewpoint. This data was transformed from aligned reads shown in the BAM file to GRanged object by using Rsamtools.
The example aligned reads generated by 3C-Seq protocol from fetal liver. The promoter region of the Myb's gene was selected as the viewpoint. This data was transformed from aligned reads shown in the BAM file to GRanged object by using Rsamtools.
Plot domainogram of interaction regions near the viewpoint
plotDomainogramNearViewpoint(object,smoothing.parameter=0.1,distance=5e5,maximum_window=25e3,view=c("experiment","control","both"))plotDomainogramNearViewpoint(object,smoothing.parameter=0.1,distance=5e5,maximum_window=25e3,view=c("experiment","control","both"))
object |
r3Cseq or r3CseqInBatch object |
smoothing.parameter |
A level at which cubic smoothing spline for the spar (see vsmooth.spline) input parameter. Must be in (0.06,0.4] (default=0.1) |
distance |
Numeric. The distance relative to the viewpoint (default=5e5) |
maximum_window |
Numeric. The maximum windowing (default=25e3). We normally compute the interaction regions per window starting from 2Kb to maximum window (default=25kb) to make the interaction matrix for visualizing the domainogram. |
view |
character. The selected view of data (default="experiment") |
Plots of domainogram for interaction regions close to the viewpoint
S. Thongjuea
plotOverviewInteractions, plotInteractionsPerChromosome,
plotInteractionsNearViewpoint
# See the vignette# See the vignette
Plot identified interaction regions near the viewpoint
plotInteractionsNearViewpoint(obj,distance=5e5,log2fc_cutoff=1,yLim=0)plotInteractionsNearViewpoint(obj,distance=5e5,log2fc_cutoff=1,yLim=0)
obj |
obj is r3Cseq or r3CseqInBatch object |
distance |
Numeric. The distance relative to the viewpoint (default=5e5) |
log2fc_cutoff |
Numeric. The log2 cutoff ratio between the experiment and control (default=1) |
yLim |
Numeric. The limited height of y-axis (default=0) |
Plots of identified interaction regions close to the viewpoint
S. Thongjuea
plotOverviewInteractions, plotInteractionsPerChromosome,
plotDomainogramNearViewpoint
# See the vignette# See the vignette
Plot the distribution of interaction regions per each chromosome
plotInteractionsPerChromosome(obj, chromosomeName)plotInteractionsPerChromosome(obj, chromosomeName)
obj |
obj is r3Cseq or r3CseqInBatch object. |
chromosomeName |
Character. The input chromosome name (e.g. "chr1") |
Plots of interaction regions per chromosome.
S. Thongjuea
plotInteractionsNearViewpoint, plotOverviewInteractions,
plotDomainogramNearViewpoint
# See the vignette# See the vignette
Plot the distribution of identified interaction regions across genome
plotOverviewInteractions(obj, cutoff.qvalue=0.05)plotOverviewInteractions(obj, cutoff.qvalue=0.05)
obj |
obj is r3Cseq or r3CseqInBatch object |
cutoff.qvalue |
Numeric. The cutoff q-value (default=0.05) |
Plots of identified 3C-Seq interaction regions genome-wide
S. Thongjuea
plotInteractionsNearViewpoint, plotInteractionsPerChromosome,
plotDomainogramNearViewpoint
# See the vignette# See the vignette
The r3Cseq class is the extended class from r3CseqCommon class. It is a general container for storing and manipulating a set of input parameters, RangeData of interactions regions from r3Cseq analysis , and the raw reads GRanged data of the genome-wide interaction signal generated by next-generation sequencing.
Class r3CseqCommon, directly.
organismNameObject of class "character" the version of
particular assembly genome from UCSC (e.g. mm9, hg18, hg19) . The package supports
three genome assemblies consisting of mouse (mm9), and human (hg18, hg19).
restrictionEnzymeObject of class "character" this is the primary
restriction enzyme name using in 3C-Seq experiment
viewpoint_chromosomeObject of class "character"
chromosome name of where is the viewpoint located eg. chr10, chrX etc.
viewpoint_primer_forwardObject of class "character"
the forward primer DNA sequences for the viewpoint amplification
viewpoint_primer_reverseObject of class "character"
the reverse primer DNA sequences for the viewpoint amplification
expReadCountObject of class "RangedData"
the read count in experiment
contrReadCountObject of class "RangedData"
the read count in control
expRPMObject of class "RangedData"
the normalized read read per million in experiment
contrRPMObject of class "RangedData"
the normalized read read per million in control
expInteractionRegionsObject of class "RangedData"
the identified interaction regions in experiment
contrInteractionRegionsObject of class "RangedData"
the identified interaction regions in control
isControlInvolvedObject of class "logical"
the logical to ask whether the control is involved in the analysis or not
alignedReadsBamExpFileObject of class "character"
the file name of experiment in BAM format
alignedReadsBamContrFileObject of class "character"
the file name of control in BAM format
expLabelObject of class "character"
the experiment name
contrLabelObject of class "character"
the control name
expLibrarySize Object of class "integer"
the library size of experiment
contrLibrarySize Object of class "integer"
the library size of control
expReadLengthObject of class "integer"
the read length of experiment
contrReadLengthObject of class "integer"
the read length of experiment
expRawDataObject of class "GRanges"
the raw reads found in experiment
contrRawDataObject of class "GRanges"
the raw reads found in control
S. Thongjuea
# See the vignette# See the vignette
The r3CseqCommon class is a general container for storing and manipulating a set of input parameters, RangeData of interactions regions from r3Cseq analysis. It is a root class for r3Cseq and r3CseqInBatch classes.
organismNameObject of class "character" the version of
particular assembly genome from UCSC (e.g. mm9, hg18, hg19) . The package supports
three genome assemblies consisting of mouse (mm9), and human (hg18, hg19).
restrictionEnzymeObject of class "character" this is the primary
restriction enzyme name using in 3C-Seq experiment
viewpoint_chromosomeObject of class "character"
chromosome name of where is the viewpoint located eg. chr10, chrX etc.
viewpoint_primer_forwardObject of class "character"
the forward primer DNA sequences for the viewpoint amplification
viewpoint_primer_reverseObject of class "character"
the reverse primer DNA sequences for the viewpoint amplification
expReadCountObject of class "RangedData"
the read count in experiment
contrReadCountObject of class "RangedData"
the read count in control
expRPMObject of class "RangedData"
the normalized read read per million in experiment
contrRPMObject of class "RangedData"
the normalized read read per million in control
expInteractionRegionsObject of class "RangedData"
the identified interaction regions in experiment
contrInteractionRegionsObject of class "RangedData"
the identified interaction regions in control
isControlInvolvedObject of class "logical"
the logical to ask whether the control is involved in the analysis or not
S. Thongjuea
# See the vignette# See the vignette
The r3CseqInBatch class is the extended class from r3CseqCommon class. It is a general container for storing and manipulating a set of input parameters, RangeData of interactions regions from r3Cseq analysis for replicates data sets.
Class r3CseqCommon, directly.
organismNameObject of class "character" the version of
particular assembly genome from UCSC (e.g. mm9, hg18, hg19) . The package supports
three genome assemblies consisting of mouse (mm9), and human (hg18, hg19).
restrictionEnzymeObject of class "character" this is the primary
restriction enzyme name using in 3C-Seq experiment
viewpoint_chromosomeObject of class "character"
chromosome name of where is the viewpoint located eg. chr10, chrX etc.
viewpoint_primer_forwardObject of class "character"
the forward primer DNA sequences for the viewpoint amplification
viewpoint_primer_reverseObject of class "character"
the reverse primer DNA sequences for the viewpoint amplification
expReadCountObject of class "RangedData"
the read count in experiment
contrReadCountObject of class "RangedData"
the read count in control
expRPMObject of class "RangedData"
the normalized read read per million in experiment
contrRPMObject of class "RangedData"
the normalized read read per million in control
expInteractionRegionsObject of class "RangedData"
the identified interaction regions in experiment
contrInteractionRegionsObject of class "RangedData"
the identified interaction regions in control
isControlInvolvedObject of class "logical"
the logical to ask whether the control is involved in the analysis or not
bamFilesDirectoryObject of class "character"
the path name of directory that contains BAM files
BamExpFilesObject of class "vector"
the file names of BAM files in the experiment
BamContrFilesObject of class "vector"
the file names of BAM files in the control
expBatchLabelObject of class "vector"
the labeled experiment names
contrBatchLabelObject of class "vector"
the labeled control names
readCountTableObject of class "RangedData"
the read count table
RPMsTableObject of class "RangedData"
the normalized read per million table
expBatchLibrarySizeObject of class "vector"
the library size of each experiment
contrBatchLibrarySizeObject of class "vector"
the library size of each control
expBatchReadLengthObject of class "vector"
the read length of experiments
contrBatchReadLengthObject of class "vector"
the read length of controls
S. Thongjuea
# See the vignette# See the vignette